# Usage

- [Getting started](getting-started.md#getting-started)
- [Installation](installation.md#installation)
- [CI Configuration](ci-configuration.md#ci-configuration)
- [Configuration](configuration.md#configuration)
- [Plugins](plugins.md)
- [Workflow configuration](workflow-configuration.md)
- [Shareable configurations](shareable-configurations.md)
